;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x308ca5cb89a1ccc8d62e86b587f180b8 . "./code.cg2js/cg-common-control.fasl")
(#xcd011e3123b66a3cc01f683df8058d43 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xda383309db5a3145d50a293b55f9769b . "./code.cg2js/cg-yes-no-string.fasl")
(#x9b17dbaaa9ac6efdec8f631329ae0b9c . "./code.cg2js/cg-clipboard.fasl")
(#x8cc2e3f36d32cd2c949579b4627f8cc0 . "./code.cg2js/cg-dde-utils.fasl")
(#x6650893ddf905115b8799b8c7c41f865 . "./code.cg2js/cg-editable-text.fasl")
(#x9ae95482bc2a9527b0c3a2d2585d0e35 . "./code.cg2js/cg-text-or-combo.fasl")
(#x43fc724e59fc811e50636b9d1d0f103a . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x97f97ad7af20261b94ba8e4d1409533d . "./code.cg2js/cg-graphics-context.fasl")
(#x6318465e46e1c41c726967d212962a3f . "./code.cg2js/cg-choose-printer.fasl")
(#x4a6bb4d860e7389d6abec04077f9a6a2 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xfe717b03682cc0140adf473946255570 . "./code.cg2js/cg-edit-in-place.fasl")
(#x50afd9a42af2f138ab4e3e4c0409b311 . "./code.cg2js/cg-split-bar.fasl")
(#xd2b4001159e73570b688a0689e22fa92 . "./code.cg2js/cg-timer.fasl")
(#xadf65cc4749789af61e34c00e952d02c . "./code.cg2js/cg-progress-indicator.fasl")
(#xb8d6a9d0ce6d23d24d720d9ed5a36b20 . "./code.cg2js/cg-object-editor.fasl")
(#x51bece2825acb4a4eb2f1cb662924fd2 . "./code.cg2js/cg-fill-texture.fasl")
(#x5a128108f56b4be211fef8b27cd379ac . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x934cd17270d82bb7e2630809ffb6999e . "./code.cg2js/cg-os-window.fasl")
(#x92394e432c1cec97ae88b89073f9b62c . "./code.cg2js/cg-color-dialog.fasl")
(#xeaec967cefd5b5169146bd6458cc8142 . "./code.cg2js/cg-combo-box.fasl")
(#x4e0c00173651341924deecef1901b9b0 . "./code.cg2js/cg-directory-dialog.fasl")
(#xef414da7ca8fc817c9be7deeca323c70 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xad25e759dd73f2d92ccab82db44cccdd . "./code.cg2js/cg-tooltip.fasl")
(#x8b37c74eb6c9243bc16a3ca2bdc585c8 . "./code.cg2js/cg-lettered-menu.fasl")
(#xabd3378f0f1fdf1d0c81dd4666867853 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x014dc2e321e2adeabd8cd7c1f27af96f . "./code.cg2js/cg-pixmap.fasl")
(#x9733129a9de7c719ef67920f3a1aa5dd . "./code.cg2js/cg.fasl")
(#x02d87d9fb8aa97db1d3e8e2601b68ac1 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xf728c8ab8bdcdb0adcf3333e039c67df . "./code.cg2js/cg-template-string.fasl")
(#xb76aabd4d9cac951ae8cec3b8edc1857 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xcbff2e3e80f9d45f1f902c1311aecc64 . "./code.cg2js/cg-check-box.fasl")
(#xb5e5fc1da70b59e2d171f8488786881c . "./code.cg2js/cg-toggling-widget.fasl")
(#x5a86c94556d925eb535081b28774ef7e . "./code.cg2js/cg-radio-button.fasl")
(#x7b0a3cf1f39e68290c766456b035a87f . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x56154485349f9dc7e0c6c07d80dea9dc . "./code.cg2js/cg-scaling-stream.fasl")
(#xeabec66c96275c41ed7e53a435fec33a . "./code.cg2js/cg-multi-picture-button.fasl")
(#x44cac95094cd72348c026426d49d3827 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xb4790a770bf0ada003ab96d2df3165f5 . "./code.cg2js/cg-grid-widget.fasl")
(#xd1f7f9fbb606751d4d0aa8c5b035f766 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x7269cfd8218082097180ff23a9fb5086 . "./code.cg2js/cg-item-list.fasl")
(#xbf5d7c8cabd12eb0da44a571c8ccf11a . "./code.cg2js/cg-paren-matching.fasl")
(#x23b48b6e55f66e618f53dda64592acf2 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x928905b5807e48afeed2fc36e18d6ce7 . "./code.cg2js/cg-html-dialog.fasl")
(#xf9b15e165d180e7545184f3114704715 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x91ac0d285470ce9b3293264865ce5ca0 . "./code.cg2js/cg-project-window.fasl")
(#x18e15b1dfb6f1284598f2f7fa65e6dd7 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x004953a2371b3bf1a1c9b5298d8222a4 . "./code.cg2js/cg-toolbar.fasl")
(#xc1c289dd09957d3f3122bf3965cee2cc . "./code.cg2js/cg-caret.fasl")
(#xdb81a83aeba53c18a071ada7aaabe164 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa8a0d709e9c6cb1df99856082e87522f . "./code.cg2js/cg-web-browser.fasl")
(#x1f63081f8deb7781bfbca2e9bf877310 . "./code.cg2js/cg-dropping-outline.fasl")
(#x7495f2585974c0bcb10cb374b89bfdb3 . "./code.cg2js/cg-font-dialog.fasl")
(#xd134299fe7d9c9e07d843e1aeb75e823 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x851682b5c32d6df112bf4d5e067ed2dc . "./code.cg2js/cg-yes-no-list.fasl")
(#xe3ef3be7a0cd917300f42d96103b6f69 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x729d1076b443755a3d037fd69d2dc198 . "./code.cg2js/cg-lamp.fasl")
(#x15a814273cb53f78ac6ffe3b8338255d . "./code.cg2js/cg-drawable.fasl")
(#x12a18c394277f4ebd094f68c89af63e8 . "./code.cg2js/cg-choice-list.fasl")
(#xb8d38b9271f9f7b6932db39c05c19462 . "./code.cg2js/cg-curve.fasl")
(#x5f14064c039cd2c228da57fcdcb447f1 . "./code.cg2js/cg-base.fasl")
(#x97311b9d67b949f46b905d3de6d6c94b . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x97f0922965c6085887e29fd7151d85e2 . "./code.cg2js/cg-printing.fasl")
(#x9524bbcf5cc47a23a6a63b9f6214937a . "./code.cg2js/cg-chart-or-plot.fasl")
(#xa792d0516bd97f600b08fd2cf4dcdcdb . "./code.cg2js/cg-hotspot.fasl")
(#x272583e98c2aad9b5207412399aa3a4e . "./code.cg2js/cg-object-editor-layout.fasl")
(#xfbf169c21467e9537c315512b57c078d . "./code.cg2js/cg-utility-dialog.fasl")
(#x3c2947e6adf67329bab817ad05bcb04b . "./code.cg2js/cg-shortcut-menu.fasl")
(#x0a274385506f40d443e3fb88eee63d69 . "./code.cg2js/cg-comtab.fasl")
(#x7ad2d9c1f2bb81983704e56083fe7d43 . "./code.cg2js/cg-os-widget.fasl")
(#x49973cf30ed19ee66167843ba87d6706 . "./code.cg2js/cg-icon.fasl")
(#x0dd6300635dae9c383d0aeb790fd9ed1 . "./code.cg2js/cg-dev.fasl")
(#xde54c6b8f0061db3b3e7cf105790f3be . "./code.cg2js/cg-calendar.fasl")
(#x8d76abf12b068eae4c4695b73024b9bb . "./code.cg2js/cg-group-box.fasl")
(#x29fd8fa10aad3a35ef54859976becfbf . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xed290fb42ffe7965de92e922840ff70b . "./code.cg2js/cg-bitmap-pane.fasl")
(#x46c346008dfcf72f0ed3b3430ab3840a . "./code.cg2js/cg-drag-and-drop.fasl")
(#x586f20c85b7ccb58a49e4b3c7bc2d2b7 . "./code.cg2js/cg-nodes.fasl")
(#x2b57000080e6fc81d8f80ca160964956 . "./code.cg2js/cg-intersect.fasl")
(#x5f017ac313a88f9d2e3a4dee6df10d0a . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x8200a61b31663bb69d15cd6bcf898b48 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x807018faeffe7767b63b539fd0fbeb0f . "./code.cg2js/cg-class-support.fasl")
(#x9d8bf5c4640a9e7452f654116905d33e . "./code.cg2js/cg-dialog-item.fasl")
(#xd6641e331b047ba28c27ff6ef82810ae . "./code.cg2js/cg-plot-widget.fasl")
(#xcc8e8df0ae9388d5e5c486da5ce174e6 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x0a44093d964d6c26503cdaaa5ab17d1a . "./code.cg2js/cg-up-down-control.fasl")
(#x28c43fbf71fabb580c130ca40ea61a7a . "./code.cg2js/cg-rich-edit.fasl")
(#x9c5726858ffb8483ac230dd73e39bf42 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x6fa17619eac0227f7509492167b7740f . "./code.cg2js/cg-status-bar.fasl")
(#x75f5c9f7d2b3639c73004ff47087452c . "./code.cg2js/cg-class-grid.fasl")
(#x2f557ce0f48feb3e3257f7c8be9c76e4 . "./code.cg2js/cg-wrap-string.fasl")
(#x4f2f041ba33aaad78c2823f3716ab6d9 . "./code.cg2js/cg-layout.fasl")
(#x0ee913eb0e01ff642fe18319c9069897 . "./code.cg2js/cg-lisp-widget.fasl")
(#x534f69ea4a2183a92b52731b12744e50 . "./code.cg2js/cg-button.fasl")
(#x6bc5796c6c317fe67d41f45f3c124e63 . "./code.cg2js/cg-string-dialog.fasl")
(#x9f4fce6c99ae25e5d0fe2907a588c512 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x2496beb49e890e5dea04a98c8a53d3c3 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xae5a2d30ade3d0b54e4667eea15e762d . "./code.cg2js/cg-bitmap-stream.fasl")
(#xb0638099ac65dc8c8100e0460ec548fc . "./code.cg2js/cg-static-text.fasl")
(#x921413c33754a99622cc66eb4ac1e806 . "./code.cg2js/cg-outline.fasl")
(#xa665490507f1f75eadc1bf7d2401942c . "./code.cg2js/cg-gesture-emulation.fasl")
(#x5f71e22811b2dbeaf938fac845c3f59a . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x6e12e273336ca82e713eea4385d93047 . "./code.cg2js/cg-picture-widget.fasl")
(#xb6ab07c7b5ce03e29ad6e483789d0fca . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xa8628a316bfadd31252664f1fe73ae38 . "./code.cg2js/cg-chart-widget.fasl")
(#xf91e187bcd924443d0c1c5b070c13cb6 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xae5e1ab6f249d21d2fb01067d7214618 . "./code.cg2js/cg-lisp-text.fasl")
(#x1f9bdf50a32799196fa71d1b9e4f749d . "./code.cg2js/cg-palette.fasl")
(#x04e63cc75698353f70aed1964fe899fd . "./code.cg2js/cg-property.fasl")
(#x3fbda3087da271a26f4d1a69b37d9299 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x83a104dc7d2c94c75d0204f97e88851a . "./code.cg2js/cg-file-dialog.fasl")
(#x7007cf7ad4ca893b70625bdbcb5f0ab5 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xeae3fc8984bd24cc214cb323fa8c0513 . "./code.cg2js/cg-get-pixmap.fasl")
(#x235fca0e102fe30e4a7628482ee24d22 . "./code.cg2js/cg-tray.fasl")
(#x9d145630c1da2a56f3af7dcd83220648 . "./code.cg2js/cg-acache.fasl")
(#xb722eb0f15198da40966cf4f62193a90 . "./code.cg2js/cg-message-dialog.fasl")
(#x7bb6a718a15f0d52651b71176105267d . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xdc79f60e4f1ede116ce6876912ba05ac . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x712e922a62342e4438582a3ea55c4bdf . "./code.cg2js/cg-tab-control.fasl")
(#x39a362ab1097c3ae68e4a2f4237e9a80 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x17e5f4405228d3840bd7672c04c8606b . "./code.cg2js/cg-menu-tooltip.fasl")
(#x50b305b3043d239e102b9485abb38984 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xea9546990bdd59d668eb1d1247d60123 . "./code.cg2js/cg-menu.fasl")
(#xba24cff81feaaf3cdcaad20e6606b3ff . "./code.cg2js/cg-get-position.fasl")
(#x0a4baaebd2a4c152fccdc0dcf2fa55f0 . "./code.cg2js/cg-trackbar.fasl")
(#x16dc42de038e0f2caa5de410e8c6bc23 . "./code.cg2js/cg-selected-object.fasl")
(#x1dbda8781a0523412fc5d45fc01873d5 . "./code.cg2js/cg-list-view.fasl")
(#x26b29967c849b42b3216cb97b73fcf7c . "./code.cg2js/cg-html-widget.fasl")
(#xeea76b2ce896613fd5c81b59228ff527 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x3386aadfb5ca6dad574b2caefd7f54fd . "./code.cg2js/cg-text-widget.fasl")
(#x36a97f96bbadc913be00a94ebdf45ff3 . "./code.idejs/ide-base.fasl")
(#x47b45d97b33fc331d167e41dec4090ab . "./code.idejs/ide-process-browser.fasl")
(#x254d434d884239d4c33aebcf155ef1d2 . "./code.idejs/ide-patch-dialog.fasl")
(#x1ebfd5d7646e25ed5b348d995fa75eca . "./code.idejs/ide-keyshort.fasl")
(#xa67b7193ca16a498b5919a05ace3f1aa . "./code.idejs/ide-window-list.fasl")
(#xc93333995cb389c8783a7714193c78cc . "./code.idejs/ide.fasl")
(#xa035ea6f721430322ff3f1b9fa9438e1 . "./code.idejs/ide-editor.fasl")
(#x6e94b948362ef30e9ddeaa229624fdda . "./code.idejs/ide-clipboard.fasl")
(#x73e1b9f807e97c633bed37a6a5928a19 . "./code.idejs/ide-trace.fasl")
(#x5b578d31f1854233f0e476667c9bb432 . "./code.idejs/ide-class-browser.fasl")
(#x6a61f504bd8602acb39f330109d7842c . "./code.idejs/ide-grapher.fasl")
(#xa965ea0993999d042df3c38f16b00d37 . "./code.idejs/ide-apropos.fasl")
(#x3da82748b7e622227ce75266e3c2c3f1 . "./code.idejs/ide-navigator.fasl")
(#x247e9092fc6f34b3de891f7f85fe379b . "./code.idejs/ide-find-definitions.fasl")
(#x86673a4415e7d627b35f0193cadf81bc . "./code.idejs/ide-project.fasl")
(#xec1f4e4761e3aefbb43f8d42da7a56bf . "./code.idejs/ide-class-grapher.fasl")
(#xca7ede6da7b4bcbc09788537f32498b9 . "./code.idejs/ide-acache.fasl")
(#xaf18d29158997d38f8ad59704c1515b6 . "./code.idejs/ide-find-in-files.fasl")
(#x41a02bbf22ed4e9f99193c49966c3648 . "./code.idejs/ide-inspector.fasl")
(#x7063af6b14ba5520856e276ade3943ba . "./code.idejs/ide-intro.fasl")
(#xe78e230cdc0a44ad7f192b025cb7085a . "./code.idejs/ide-package-list.fasl")
(#x008bd86de1b9efe788e147de957b728c . "./code.idejs/ide-dev.fasl")
(#x15c0967f4acdd7cec21c0557ba7712f0 . "./code.idejs/ide-form.fasl")
(#x49a17b9a618997e974ff2e9af0f2eb06 . "./cgjs.html")
(#x44f169492307df5920f609d11cc1a34c . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
